code.tool.measure.algo-js


*js-config*clj


generate-metricsclj

(generate-metrics code)

Generates both complexity score and surface area for a given JS code string.

Generates both complexity score and surface area for a given JS code string.
raw docstring

score-astclj

(score-ast ast)
(score-ast ast config)

Calculates the structural complexity score of an AST map.

Calculates the structural complexity score of an AST map.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries