(generate-metrics code)Generates both complexity score and surface area for a given JS code string.
Generates both complexity score and surface area for a given JS code string.
(score-ast ast)(score-ast ast config)Calculates the structural complexity score of an AST map.
Calculates the structural complexity score of an AST map.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |